tiled.client.cache.Cache
========================

.. currentmodule:: tiled.client.cache

.. autoclass:: Cache

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Cache.__init__
      ~Cache.clear
      ~Cache.get_reservation
      ~Cache.in_memory
      ~Cache.on_disk
      ~Cache.put
      ~Cache.renew
      ~Cache.resize
      ~Cache.retire
      ~Cache.shrink
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Cache.when_full
   
   